@@ -69,23 +69,7 @@ class FreqDict(models.Model):
     def loadWF(self):
         wfs = self.loadOrthWF()
         wfs = self.loadTransWF(wfs)
-        wfss = []
-        ts = []
-        ss = []
-        for key in wfs:
-            lem = Lemma.objects.filter(pk=int(wfs[key]['IdLemma']))
-            if len(lem) != 1:
-                continue
-            wfss.append(WordForm(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq'])))
-            ts.extend([Transcription(Transcription=t
-                    ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
-                                re.sub('[IE{VQU@i#$u312456789cq0~]','V',
-                                re.sub(r'[-"\']','',t))))
-                    for t in wfs[key]['Transcriptions']])
-            ss.extend(Orthography(Spelling=s) for s in wfs[key]['Spellings'])
-        WordForm.objects.bulk_create(wfss)
-        Transcription.objects.bulk_create(ts)
-        Orthography.objects.bulk_create(ss)
+        wfss = WordForm.objects.all()
         for w in wfss:
             #ts = [Transcription(Transcription=t
             #        ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
@@ -153,6 +137,8 @@ class FreqDict(models.Model):
         return lemmas
 
     def loadOrthWF(self):
+        wfss = []
+        ss = []
         wfs = {}
         with open(fetch_celex_resource('Orthography/celex-orthography-wordforms.txt'),'r') as f:
             head = None
@@ -165,14 +151,22 @@ class FreqDict(models.Model):
                 additional = l[9:]
                 spellings = [l[1]]
                 nl = {'IdLemma':l[3],'Freq':l[2]}
+                lem = Lemma.objects.filter(pk=int(nl['IdLemma']))
+                if len(lem) != 1:
+                    continue
+                wfss.append(WordForm(pk=int(main[0]),Lemma = lem[0],Frequency = int(nl['Freq'])))
                 if len(additional) != 0:
                     additional = chunks(additional,5)
                     spellings.extend([x[1] for x in additional])
                 nl['Spellings'] = set(spellings)
+                ss.extend(Orthography(Spelling=s) for s in nl['Spellings'])
                 wfs[main[0]] = nl
+        WordForm.objects.bulk_create(wfss)
+        Orthography.objects.bulk_create(ss)
         return wfs
 
     def loadTransWF(self,wfs):
+        ts = []
         with open(fetch_celex_resource('Phonology/celex-phonology-wordforms.txt'),'r') as f:
             head = None
             for line in f:
@@ -187,6 +181,12 @@ class FreqDict(models.Model):
                     additional = chunks(additional,4)
                     trans.extend([x[1] for x in additional])
                 wfs[main[0]]['Transcriptions'] = set(trans)
+                ts.extend([Transcription(Transcription=t
+                    ,CVSkel=re.sub('[^IE{VQU@i#$u312456789cq0~]','C',
+                                re.sub('[IE{VQU@i#$u312456789cq0~]','V',
+                                re.sub(r'[-"\']','',t))))
+                        for t in trans])
+        Transcription.objects.bulk_create(ts)
         return wfs
 
 
